@@ -176,7 +176,8 @@ def create_label(
         padding_bottom = None,
         border_width = 0,
         border_color = "#ffffff",
-        border_radius = 0
+        border_radius = 0,
+        hover_background_color = "#1e1e1e"
 ):
     label = QLabel(text)
     padding_left_value = padding_left if padding_left is not None else padding
@@ -184,17 +185,22 @@ def create_label(
     padding_right_value = padding_right if padding_right is not None else padding
     padding_bottom_value = padding_bottom if padding_bottom is not None else padding
     style = f"""
-        font-family: {font_family};
-        font-size: {font_size}px;
-        color: {font_color};
-        font-weight: {font_weight};
-        background-color: {background_color};
-        padding-left: {padding_left_value}px;
-        padding-top: {padding_top_value}px;
-        padding-right: {padding_right_value}px;
-        padding-bottom: {padding_bottom_value}px;
-        border: {border_width}px solid {border_color};
-        border-radius: {border_radius}px;
+        QLabel {{
+            font-family: {font_family};
+            font-size: {font_size}px;
+            color: {font_color};
+            font-weight: {font_weight};
+            background-color: {background_color};
+            padding-left: {padding_left_value}px;
+            padding-top: {padding_top_value}px;
+            padding-right: {padding_right_value}px;
+            padding-bottom: {padding_bottom_value}px;
+            border: {border_width}px solid {border_color};
+            border-radius: {border_radius}px;
+        }}
+        QLabel:hover{{
+            background-color: {hover_background_color};
+        }}
     """
     label.setStyleSheet(style)
     return label
@@ -227,20 +233,15 @@ def create_button(
 ):
     button = QPushButton()
     button.setMaximumWidth(360)
+    main_layout = QVBoxLayout(button)
+    label = create_label(text = text, font_size = 16, font_weight = "bold", padding = 5, hover_background_color = "#333333")
+    label.setAlignment(Qt.AlignmentFlag.AlignCenter)
+    label.setWordWrap(True)
+    main_layout.addWidget(label)
     padding_left_value = padding_left if padding_left is not None else padding
     padding_top_value = padding_top if padding_top is not None else padding
     padding_right_value = padding_right if padding_right is not None else padding
     padding_bottom_value = padding_bottom if padding_bottom is not None else padding
-    max_text_width = 360 - padding_left_value - padding_right_value - 2 * border_width
-    font = QFont(font_family, font_size)
-    if font_weight == "bold": font.setWeight(QFont.Weight.Bold)
-    else: font.setWeight(QFont.Weight.Normal)
-    metrics = QFontMetrics(font)
-    text_width = metrics.horizontalAdvance(text)
-    if text_width > max_text_width:
-        html_text = f"<div style = \"white-space: normal; text-align: center;\">{text}</div>"
-        button.setText(html_text)
-    else: button.setText(text)
     style_sheet = f"""
         QPushButton {{
             font-family: {font_family};
